#!/bin/bash

# This script will do a rescan of the imdb info in current dir (and dirs
# directly below the current dir). The script should be set up as a site
# command.
# syntax is:
# site imdb-rescan [-1|-r]

# 1. edit the config below
# 2. copy this file to /glftpd/bin
# 3. add the following in glftpd.conf
#       site_cmd IMDB-RESCAN EXEC /bin/psxc-imdb-rescan.sh
#       custom-imdb-rescan   1 =staff
#
# syntax is:
# site imdb-rescan [-1|-r]

# config
########

# Version. No need to change.
VERSION=2.1

# Path to psxc-imdb.sh. This is relative to GLROOT.
PSXC_IMDB=/bin/psxc-imdb.sh

# Nukedir style. We don't want to rescan nuked dirs, so put here
# the output of this line:
#
# cat /etc/glftpd.conf | grep -e "^nukedir_style" | awk '{print $2}' | tr '%' '\n' | head -n 1
#
NUKEDIR_STYLE="[NUKED]-"

# end of config
###############

if [ $# -eq 0 ]; then
 echo "PSXC's imdb rescanner."
 echo "----------------------"
 echo "Syntax:"
 echo "site imdb-rescan [-i|-r]"
 echo "  -i = scan current dir"
 echo "  -r = scan all dirs below current"
 echo ""
 echo "Use caution - chanflooding may occur."
 exit 0
fi
ARG=$1
if [ ! "$ARG" = "-r" ]; then
 echo "Doing a scan in current dir .. searching for iMDB info."
 IMDB_NFO="`ls -1 | grep -e "[.][Nn][Ff][Oo]" | head -n 1`"
 if [ ! -z "$IMDB_NFO" ]; then
  $PSXC_IMDB $IMDB_NFO
 fi
 echo "Done."
 exit 0
else
 echo "Scanning for iMDB info.."
 for REL_DIR in `ls -1F | grep -e "/" | grep -F -v "^$NUKEDIR_STYLE" | tr ' ' '%'`; do
  REL_DIR="`echo $REL_DIR | tr '%' ' '`"
  echo "$REL_DIR ..."
  cd "$REL_DIR"
  IMDB_NFO="`ls -1 | grep -e "[.][Nn][Ff][Oo]" | head -n 1`"
  if [ ! -z "$IMDB_NFO" ]; then
   $PSXC_IMDB $IMDB_NFO
  fi
  cd ..
 done
 echo "Done."
 exit 0
fi

